@@ -6,7 +6,7 @@ from sklearn.datasets import make_moons
 
 class HalfMoonIterator(DatasetIterator):
 
-    def __init__(self, seed: int, noise_std: float, num_samples: List[int], translation: List[int] = None):
+    def __init__(self, seed: int, noise_std: float, num_samples: List[int], translation: List[float] = None, scaling: List[float] = None):
         """
         Creates a dataset iterator over the function x -> x^3 + e, where e ~ N(0, noise_std^2).
 
@@ -17,6 +17,8 @@ class HalfMoonIterator(DatasetIterator):
         """
         self.X, self.y = make_moons(n_samples=num_samples, shuffle=True, noise=noise_std, random_state=seed)
         self.X = torch.Tensor(self.X)
+        if scaling is not None:
+            self.X = self.X * torch.Tensor(scaling)
         if translation is not None:
             self.X = self.X + torch.Tensor(translation)
         self.y = torch.IntTensor(self.y)
